Page
Library
Module
Module type
Parameter
Class
Class type
MlFront adds a Java-like packaging system to OCaml. The MlFront name is a homage to cfront which was tooling that translated "C with Classes" (now known as C++) into C code. Similarly, MlFront-based tools can translate OCaml with packages into conventional OCaml.
MlFront is also a build system which is documented at https://github.com/diskuv/dk.git
The intent of the licensing is to encourage you to create and use permissively-licensed, community-supported implementations of the build system, while also encouraging contributions to the reference implementation dk0 to go to one place: https://gitlab.com/dkml/build-tools/MlFront.git.
The MlFront_* and UnifiedScript_* subprojects in src/ and tests/ are permissively licensed under Apache 2.0.
The dependencies codept_lib and the ocaml standard library both have a weakly restrictive LGPL-based license.
All remaining code, scripts, specifications and documentation in https://gitlab.com/dkml/build-tools/MlFront.git, including the reference implementation DkZero_* subprojects in src/ and tests/, and including the executable dk0, are licensed under the Open Software License version 3.0 (OSL 3.0) or DkSDK SOFTWARE DEVELOPMENT KIT LICENSE AGREEMENT, at your option. A guide to the OSL 3.0 is available at https://rosenlaw.com/OSL3.0-explained.htm.